#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 classy-prelude
version:              1.5.0.3
visibility:           public
id:                   classy-prelude-1.5.0.3-G9eRBoppWE34C5j4MYSIFD
key:                  classy-prelude-1.5.0.3-G9eRBoppWE34C5j4MYSIFD
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             A typeclass-based Prelude.
description:
    See docs and README at <http://www.stackage.org/package/classy-prelude>

category:             Control, Prelude
abi:                  dc660e797b9f003d2138d67d6d232642
exposed:              True
exposed-modules:      ClassyPrelude
hidden-modules:       Paths_classy_prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/classy-prelude-1.5.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/classy-prelude-1.5.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/classy-prelude-1.5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-classy-prelude
hs-libraries:         HSclassy-prelude-1.5.0.3-G9eRBoppWE34C5j4MYSIFD
depends:
    async-2.2.6-8zdvXX2Zsrb75FFkoyfONv base-4.18.2.1
    basic-prelude-0.7.0-BEIp4iaekHp7h3eOJ8r0OL
    bifunctors-5.6.3-5jGMFLLdDBXFmRemSd7XH6 bytestring-0.11.5.3
    chunked-data-0.3.1-JCalF6rlrzRB4jCGgknDXP containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO ghc-prim-0.10.0
    hashable-1.4.7.0-7IXYIAIJ1Hk6CRw3icGaw3
    mono-traversable-1.0.21.0-IdYpVvkDEWu4iWAZmwwL57
    mono-traversable-instances-0.1.1.0-7yGslWp52ytEuBVL00rqzS mtl-2.3.1
    mutable-containers-0.3.4.1-9KdUKON65fGI3QFzNPJto7
    primitive-0.9.1.0-GuwLTClf8Ud2zByiXzaqjs
    say-0.1.0.1-DUIzbnPbeKL18V4vxuF4Vi stm-2.5.1.0
    stm-chans-3.0.0.11-FvSGcL6ts223Fah2i3K6ah text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-JnhUHQXeGEX5efNIWb5EqF
    unordered-containers-0.2.20.1-KOOMDe69vyW5LNgLyOaup0
    vector-0.13.2.0-HarLsKOX3fDLjvAK8O9pTy
    vector-instances-3.4.3-BHrOYOQfRZ656vVaMSnV6T

haddock-interfaces:
    /usr/share/doc/haskell-classy-prelude/html/classy-prelude.haddock

haddock-html:         /usr/share/doc/haskell-classy-prelude/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

